library(dplyr)
library(MuMIn)
library(lme4)
library(patchwork)
library(tidyverse)
library(emmeans)

# Read in fitted parameter data
locParComp <- read.csv('locParComp.csv') # long format
sdParComp <- read.csv('sdParComp.csv') # long format
lpcWide <- read.csv('lpcWide.csv') # wide format
sdcWide <- read.csv('sdcWide.csv') # wide format

#lme models LOC
# [NB FACTOR LABELS: OTMC = MT; MGT = AP]
# lme models using ML rather than default REML [need this as doing model comparison]
lmelocModelNull2 = lmer(par ~ (1  | PNo), data=locParComp,REML=F) #1
lmelocModelMT2 = lmer(par ~ MoveType + (1 |PNo), data=locParComp, REML=F) #2
lmelocModelAP2 = lmer(par ~ Active_Passive + (1 |PNo), data=locParComp, REML=F) #3
lmelocModelSUM2 = lmer(par ~ MoveType + Active_Passive + (1 |PNo), data=locParComp, REML=F) #4
lmelocModelFull2 = lmer(par ~ MoveType*Active_Passive + (1 |PNo), data=locParComp, REML=F) #5

#lme models SD
# [NB FACTOR LABELS: OTMC = MT; MGT = AP]
# lme models using ML rather than default REML [need this as doing model comparison]
lmeSDModelNull2 = lmer(par ~ (1  |PNo), data=sdParComp, REML=F) #1
lmeSDModelMT2 = lmer(par ~ MoveType + (1  |PNo), data=sdParComp, REML=F) #2
lmeSDModelAP2 = lmer(par ~ Active_Passive + (1 |PNo), data=sdParComp, REML=F) #3
lmeSDModelSUM2 = lmer(par ~ MoveType + Active_Passive + (1 |PNo), data=sdParComp, REML=F) #4
lmeSDModelFull2 = lmer(par ~ MoveType*Active_Passive + (1 |PNo), data=sdParComp, REML=F) #5

#AIC MODEL COMPARISON ANLYSES FOR LOC PARAM
AICloc2 = AIC(lmelocModelNull2, lmelocModelMT2, lmelocModelAP2, lmelocModelSUM2, lmelocModelFull2)
# model weights
wAICloc2 = Weights(AICloc2)

#AIC MODEL COMPARISON ANALYSES FOR SD PARAM
AICSD2 = AIC(lmeSDModelNull2, lmeSDModelMT2, lmeSDModelAP2, lmeSDModelSUM2, lmeSDModelFull2)
# model weights
wAICSD2 = Weights(AICSD2)

#Likelihood Ratio Tests PSS 
anova(lmelocModelNull2,lmelocModelMT2,"LRT") #2v1
anova(lmelocModelNull2,lmelocModelAP2,"LRT") #3v1
anova(lmelocModelNull2,lmelocModelSUM2,"LRT") #4v1
anova(lmelocModelNull2,lmelocModelFull2,"LRT") #5v1
anova(lmelocModelAP2,lmelocModelSUM2,"LRT") #4v3
anova(lmelocModelAP2,lmelocModelFull2,"LRT") #5v3
#LRTs (nesting via MT - 2v1, 4v2, 5v4) 
anova(lmelocModelNull2,lmelocModelMT2,lmelocModelSUM2,lmelocModelFull2,"LRT")
#LRTs (nesting via AP - 3v1 4v3, 5v4)
anova(lmelocModelNull2,lmelocModelAP2,lmelocModelSUM2,lmelocModelFull2,"LRT")

#Likelihood Ratio Tests SD 
anova(lmeSDModelNull2,lmeSDModelMT2,"LRT") #2v1
anova(lmeSDModelNull2,lmeSDModelAP2,"LRT") #3v1
anova(lmeSDModelNull2,lmeSDModelSUM2,"LRT") #4v1
anova(lmeSDModelNull2,lmeSDModelFull2,"LRT") #5v1
anova(lmeSDModelAP2,lmeSDModelSUM2,"LRT") #4v3
anova(lmeSDModelAP2,lmeSDModelFull2,"LRT") #5v3
#LRTs (nesting via MT - 2v1, 4v2, 5v4)
anova(lmeSDModelNull2,lmeSDModelMT2,lmeSDModelSUM2,lmeSDModelFull2,"LRT")
#LRTs (nesting via AP - 3v1 4v3, 5v4)
anova(lmeSDModelNull2,lmeSDModelAP2,lmeSDModelSUM2,lmeSDModelFull2,"LRT")

# post-hoc Tukey on SD data (to investigate where diffs are) for MoveType
em1 = emmeans(lmeSDModelSUM2, list(pairwise ~ MoveType), adjust = "tukey")
summary(em1)

# Correlations between diff conditions 
# [note only interested in A:(S1 vs S2), A:(S1 vs S5), A:(S2 vs S5)
#                          P:(S1 vs S2), P:(S1 vs S5), P:(S2 vs S5) 
lpcCor <- cor(lpcWide[,2:7], use="pairwise.complete.obs")
# Correlations between diff conditions
sdcCor <- cor(sdcWide[,2:7], use="pairwise.complete.obs")



