library(quickpsy)
library(tidyverse)
library(ggplot2)

#load pyshocmetric fits
fit <- readRDS("fit.rds")

#load summary data
locPar <- read.csv('locPar.csv')
sdPar <- read.csv('sdPar.csv')
locParComp <- read.csv('locParComp.csv')
sdParComp <- read.csv('sdParComp.csv')

pd <- position_dodge(0.9) # move data points to left and right in boxplot

#PF function fits (from quickpsy) [FIGURE 2]
plotcurves(fit, averages = TRUE, color = Active_Passive) +
  theme(legend.title = element_blank())

#location parameter
#[FIGURE 3A]
ggplot(locParComp, aes(x=MoveType, y=par, colour=Active_Passive)) + 
  geom_boxplot(position = pd) +
  geom_point(position = pd) +
  scale_x_discrete(labels=c("S1" = "(L+R):R", "S2" = "S:S", "S5" = "L:L")) +
  ylab("PSS (Bias)") + 
  xlab("Observer Movement:Target Movement") +
  theme(axis.title = element_text(size = 20)) +
  theme(axis.text = element_text(size = 16)) +
  theme(legend.title = element_blank()) +
  theme(legend.text = element_text(size = 16)) 
  
#s.d. parameter
# [FIGURE 3B]
ggplot(sdParComp, aes(x=MoveType, y=par, colour=Active_Passive)) + 
  geom_boxplot(position = pd) +
  geom_point(position = pd) +
  scale_x_discrete(labels=c("S1" = "(L+R):R", "S2" = "S:S", "S5" = "L:L")) +
  ylab("Gaussian s.d.") +
  xlab("Observer Movement : Target Movement") +
  theme(axis.title = element_text(size = 20)) +
  theme(axis.text = element_text(size = 16)) +
  theme(legend.title = element_blank()) +
  theme(legend.text = element_text(size = 16)) +
  ylim(0, 0.75)

# distance moved mis-estimate 
locParComp <- mutate(locParComp, distMisEst = 1-par)
# [FIGURE 4]
ggplot(locParComp, aes(x=MoveType, y=distMisEst, colour=Active_Passive)) + 
  geom_boxplot(position = pd) +
  geom_point(position = pd) +
  scale_x_discrete(labels=c("S1" = "(L+R):R", "S2" = "F:F", "S5" = "L:L")) +
  ylab("Normalised est. of perceived self-movement") + 
  xlab("Observer Movement:Target Movement") +
  theme(axis.title = element_text(size = 20)) +
  theme(axis.text.y = element_text(size = 12)) +
  theme(axis.text.x = element_text(size = 16)) +
  theme(legend.title = element_blank()) +
  theme(legend.text = element_text(size = 16)) 





