library(rio)
library(tidyverse)

# Concatenate participants' data files for each of the experiments/conditions:
allData <- import_list(list.files(path = "data",full.names = T),rbind = T)
allData <- rename(allData, gain = V1)
allData <- rename(allData, resp = V2)

#Get Participant no info and add to data file
Plist <-  c("P01", "P02", "P03", "P04", "P05", "P06", "P07", "P08", "P09", "P10",
            "P11", "P12", "P13", "P14", "P15", "P16")
Pmatch <- str_c(Plist, collapse = "|")
hasP <- str_subset(allData[,3], Pmatch)
allData <- mutate(allData, PNo = str_extract(hasP, Pmatch))

#Get Movement type info and add to data file (1 = L+R:R; 2 = S:S; 5 = L:L)
typeList <-  c("S1", "S2", "S5") 
typeMatch <- str_c(typeList, collapse = "|")
hasType <- str_subset(allData[,3], typeMatch)
allData <- mutate(allData, MoveType = str_extract(hasType, typeMatch))

#Get Active/Passive info and add to data file (A = Active; P = Passive)
acPasList <-  c("AS", "PS") 
acPasMatch <- str_c(acPasList, collapse = "|")
hasAcPas <- str_subset(allData[,3], acPasMatch)
acPas <- str_extract(hasAcPas, acPasMatch)
acPas <- substr(acPas,1, 1) # get character 1
allData <- mutate(allData, Active_Passive = acPas)

# save data file
write.csv(allData,'allData.csv',row.names = F)
rm(allData)
