library(quickpsy)
library(dplyr)
library(tidyverse)

allData <- read.csv('allData.csv')

#default PF fit (cum Norm?)
fit <- quickpsy(allData, gain, resp, grouping = c("PNo", "MoveType", "Active_Passive"))

saveRDS(fit, file = 'fit.rds')

# Extract parameter information for analysis and save approrpaite files
# long format
locPar = filter(fit$par, parn == "p1") # mean parameter for cum gauss
sdPar = filter(fit$par, parn == "p2")  # sd parameter for cum gauss

# complete incomplete data frames (location paramter)
locParComp <- locPar %>% complete(PNo, nesting(Active_Passive, MoveType))
write.csv(locParComp,'locParComp.csv',row.names = F)

# complete incomplete data frames (sd paramter) 
sdParComp <- sdPar %>% complete(PNo, nesting(Active_Passive, MoveType))
write.csv(sdParComp,'sdParComp.csv',row.names = F)


# wide format
#  (1 row per P, 6 cols one for each condition) 
lpcWide <- locParComp %>% pivot_wider(c(1, 2, 3, 5), 
                                       names_from = c(MoveType, Active_Passive), values_from = par)
write.csv(lpcWide,'lpcWide.csv',row.names = F)

sdcWide <- sdParComp %>% pivot_wider(c(1, 2, 3, 5), 
                                      names_from = c(MoveType, Active_Passive), values_from = par)
write.csv(sdcWide,'sdcWide.csv',row.names = F)
